==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/cms_templates_controller.rb <==
# -*- coding: utf-8 -*-
class CmsTemplatesController < ApplicationController
  class_desc :display_name => 'テンプレート管理'

  before_filter :find_cms_project

  private
  def find_cms_project
    session[:project_id] ||= params[:project_id]
    if params[:project_id] && session[:project_id] != params[:project_id]
      session[:project_id] = params[:project_id]
    end
    @cms_project = CmsProject.find(session[:project_id])
  end

  public
  # GET /cms_templates
  # GET /cms_templates.xml
  def index
    @condition = prepare_session_condition do |condition|
      condition || CmsTemplate::SearchCondition.new(params[:condition])
    end
    @condition.cms_project_id = @cms_project.id
    per_page = @condition.disp_count.to_i if @condition
    per_page = (per_page.to_i == 0) ? 20 : per_page
    cond, @delete_ids = @condition.create_condition
    @cms_templates = CmsTemplate.paginate(:include => :cms_project, :conditions => cond, :order => 'name',
                             :page => params[:page], :per_page => per_page)
  end

  # GET /cms_templates/1
  # GET /cms_templates/1.xml
  def show
    @cms_template = CmsTemplate.find(params[:id], :include => [:contents, :cms_project])
    conditions = ['cms_binds.cms_template_id = ? and cms_page_titles.locale = ? and cms_projects.status_cd <> ?',
      params[:id], 'ja', CmsProject.status_id_by_key(:closed)]
    @cms_pages = CmsPage.find(:all, :include => [{:binds => :cms_page}, :titles, :cms_project],
      :conditions => conditions, :group => 'cms_pages.controller, cms_pages.action')

    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @cms_template }
    end
  end

  # GET /cms_templates/new
  # GET /cms_templates/new.xml
  def new
    if params[:source_id]
      present_template = CmsTemplate.find(params[:source_id], :include => :contents)
      @cms_template = present_template.new_copy
    else
      @cms_template = CmsTemplate.new
      I18n.supported_locales.each do |locale|
        @cms_template.contents << CmsTemplateContent.new(:locale => locale.to_s)
      end
    end

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @cms_template }
    end
  end

  # GET /cms_templates/1/edit
  def edit
    @cms_template = CmsTemplate.find(params[:id], :include => :contents)
  end

  # POST /cms_templates
  # POST /cms_templates.xml
  def create
    if params[:source_id]
      # PJ公開時に削除する場合。コントローラ名とアクション名をコピーして公開時に削除フラグをtrueにセット
      # 一覧画面で「公開時に削除」を押した場合はここが実行されます。
      src_template = CmsTemplate.find(params[:source_id])
      cms_template = CmsTemplate.new(:cms_project_id => @cms_project.id, :delete_at_publish => true,
        :name => src_template.name, :template_code => src_template.template_code)
      cms_template.present_version_id = params[:source_id]
      cms_template.save!
      redirect_to :action => "index"
    else
      # cms_templates/new.html.erbでPOSTした場合はこちらが実行されます。
      # params[:cms_template][:cms_project_id]が本プロジェクトのidかどうかで前プロジェクトからのコピーテンプレートか、
      # 本プロジェクトで新規に作成したテンプレートかを判断しています。
      copied_cms_project_id = params[:cms_template][:cms_project_id]
      @cms_template = CmsTemplate.new(params[:cms_template].merge(:cms_project_id => @cms_project.id))
      @cms_template.set_values_for_create
      @cms_template.present_version_id = params[:cms_template][:present_version_id]

      unless @cms_template.valid?
        @cms_template.cms_project_id = copied_cms_project_id
        return render :action => "new"
      end
      @cms_template.save!
      redirect_to(@cms_template)
    end
  end

  # PUT /cms_templates/1
  # PUT /cms_templates/1.xml
  def update
    @cms_template = CmsTemplate.find(params[:id])
    @cms_template.attributes = params[:cms_template]

    CmsTemplate.transaction do
      @cms_template.save!
      @cms_template.contents.each do |content|
        content.attributes = @cms_template.contents_attributes[content.locale.intern ]
        content.save!
      end
    end
    redirect_to(:action => 'show', :id => @cms_template.id)
  rescue
    render :action => "edit"
  end

  # DELETE /cms_templates/1
  # DELETE /cms_templates/1.xml
  def destroy
    if params[:source_id]
      # 削除取り消し
      # 公開時削除のためのCmsTemplateを削除します。
      # これは 対象となるCmsTemplateのidが一覧では使い難いため、source_idで制御しています。
      src_template = CmsTemplate.find(params[:source_id])
      # このプロジェクトでのCmsTemplateを検索します。
      cms_template = CmsTemplate.find(:first,
        :conditions => ["cms_project_id = ? and template_code = ? and delete_at_publish = ?", @cms_project.id, src_template.template_code, true])
      cms_template.destroy
      redirect_to :action => "index"
    else
      # プロジェクトで編集対象になっているテンプレートを削除する
      @cms_template = CmsTemplate.find(params[:id], :include => :contents)
      CmsTemplate.transaction do
        cms_pages = CmsPage.find(:all, 
          :include => [{:binds => :cms_page}, :titles, :cms_project], 
          :conditions => ['cms_binds.cms_template_id = ?', params[:id]])
        cms_pages.each do |cms_page|
          cms_page.titles.each do|title|
            title.destroy
          end
          cms_page.binds.each do|bind|
            bind.items.each do |item|
              item.contents.each do |content|
                content.destroy
              end if item.contents
              item.destroy
            end if bind.items
            bind.destroy
          end
          cms_page.destroy
        end
        
        @cms_template.contents.each do |content|
          content.destroy
        end
        @cms_template.destroy
      end
      respond_to do |format|
        format.html { redirect_to(cms_templates_url) }
        format.xml  { head :ok }
      end
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/cms_templates_controller.rb <==
# -*- coding: utf-8 -*-
class CmsTemplatesController < ApplicationController
  class_desc :display_name => 'プロジェクト管理->テンプレート管理'

  before_filter :find_cms_project

  private
  def find_cms_project
    session[:project_id] ||= params[:project_id]
    if params[:project_id] && session[:project_id] != params[:project_id]
      session[:project_id] = params[:project_id]
    end
    @cms_project = CmsProject.find(session[:project_id])
  end

  public
  # GET /cms_templates
  # GET /cms_templates.xml
  def index
    @condition = prepare_session_condition do |condition|
      condition || CmsTemplate::SearchCondition.new(params[:condition])
    end
    @condition.cms_project_id = @cms_project.id
    per_page = @condition.disp_count.to_i if @condition
    per_page = (per_page.to_i == 0) ? 20 : per_page
    cond, @delete_ids = @condition.create_condition
    @cms_templates = CmsTemplate.paginate(:include => :cms_project, :conditions => cond, :order => 'name',
                             :page => params[:page], :per_page => per_page)
    @default_template_codes = CmsDefaultTemplate.primary_default_template_codes(CmsProject.find_all_to_be_deployed_or_deleted.map(&:id), @cms_project.id)
  end

  # GET /cms_templates/1
  # GET /cms_templates/1.xml
  def show
    @cms_template = CmsTemplate.find(params[:id], :include => [:contents, :cms_project])
    @cms_template.terminal_key == :pc ? locale = 'ja' : locale = 'docomo'
    conditions = ['cms_binds.cms_template_id = ? and cms_page_titles.locale = ? and cms_projects.status_cd <> ?',
      params[:id], locale, CmsProject.status_id_by_key(:closed)]
    @cms_pages = CmsPage.find(:all, :include => [{:binds => :cms_page}, :titles, :cms_project],
      :conditions => conditions, :group => 'cms_pages.controller, cms_pages.action')
    @default_template_codes = CmsDefaultTemplate.primary_default_template_codes(CmsProject.find_all_to_be_deployed_or_deleted.map(&:id), @cms_project.id)
    
    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @cms_template }
    end
  end

  # GET /cms_templates/new
  # GET /cms_templates/new.xml
  def new
    if params[:source_id]
      present_template = CmsTemplate.find(params[:source_id], :include => :contents)
      @cms_template = present_template.new_copy
    else
      terminal_key = :pc
      terminal_key = :mobile if params[:terminal] == CmsTemplate.terminal_id_by_key(:mobile)
      @cms_template = CmsTemplate.new(:terminal_key => terminal_key)
      if terminal_key == :pc
        I18n.supported_locales.each do |locale|
          @cms_template.contents << CmsTemplateContent.new(:locale => locale.to_s)
        end
      else
        CmsTemplateContent.carrier_ids.each do |locale|
          @cms_template.contents << CmsTemplateContent.new(:locale => locale.to_s)
        end
      end
    end
    @default_template_codes = CmsDefaultTemplate.primary_default_template_codes(CmsProject.find_all_to_be_deployed_or_deleted.map(&:id), @cms_template.cms_project_id)

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @cms_template }
    end
  end

  # GET /cms_templates/1/edit
  def edit
    @cms_template = CmsTemplate.find(params[:id], :include => :contents)
    @default_template_codes = CmsDefaultTemplate.primary_default_template_codes(CmsProject.find_all_to_be_deployed_or_deleted.map(&:id), @cms_template.cms_project_id)
  end

  # POST /cms_templates
  # POST /cms_templates.xml
  def create
    if params[:source_id]
      # PJ公開時に削除する場合。コントローラ名とアクション名をコピーして公開時に削除フラグをtrueにセット
      # 一覧画面で「公開時に削除」を押した場合はここが実行されます。
      src_template = CmsTemplate.find(params[:source_id])
      cms_template = CmsTemplate.new(:cms_project_id => @cms_project.id, :delete_at_publish => true,
        :name => src_template.name, :template_code => src_template.template_code)
      cms_template.present_version_id = params[:source_id]
      cms_template.save!
      redirect_to :action => "index"
    else
      # cms_templates/new.html.erbでPOSTした場合はこちらが実行されます。
      # params[:cms_template][:cms_project_id]が本プロジェクトのidかどうかで前プロジェクトからのコピーテンプレートか、
      # 本プロジェクトで新規に作成したテンプレートかを判断しています。
      copied_cms_project_id = params[:cms_template][:cms_project_id]
      @cms_template = CmsTemplate.new(params[:cms_template].merge(:cms_project_id => @cms_project.id))
      @cms_template.set_values_for_create
      @cms_template.present_version_id = params[:cms_template][:present_version_id]
      @cms_template.default_template_position = params[:cms_default_template][:new_position] #バリデーションチェック用

      unless @cms_template.valid?
        @cms_template.cms_project_id = copied_cms_project_id
        @default_template_codes = CmsDefaultTemplate.primary_default_template_codes(CmsProject.find_all_to_be_deployed_or_deleted.map(&:id), @cms_template.cms_project_id)
        @new_default_template_position = params[:cms_default_template][:new_position]
        return render :action => "new"
      end
      
      CmsTemplate.transaction do
        @cms_template.save!
        CmsDefaultTemplate.update_default_template_position(
          @cms_template.cms_project_id, @cms_template.template_code,@cms_template.terminal,
          params[:cms_default_template][:current_position], params[:cms_default_template][:new_position])
      end
      redirect_to(@cms_template)
    end
  end

  # PUT /cms_templates/1
  # PUT /cms_templates/1.xml
  def update
    @cms_template = CmsTemplate.find(params[:id])
    @cms_template.attributes = params[:cms_template]

    CmsTemplate.transaction do
      @cms_template.contents.each do |content|
        content.attributes = @cms_template.contents_attributes[content.locale.intern ]
        content.save!
      end
      @cms_template.default_template_position = params[:cms_default_template][:new_position] #バリデーションチェック用
      @cms_template.save!
      CmsDefaultTemplate.update_default_template_position(
        @cms_template.cms_project_id, @cms_template.template_code,@cms_template.terminal,
        params[:cms_default_template][:current_position], params[:cms_default_template][:new_position])
    end
    redirect_to(:action => 'show', :id => @cms_template.id)
  rescue
    @default_template_codes = CmsDefaultTemplate.primary_default_template_codes(CmsProject.find_all_to_be_deployed_or_deleted.map(&:id), @cms_template.cms_project_id)
    @new_default_template_position = params[:cms_default_template][:new_position]
    render :action => "edit"
  end

  # DELETE /cms_templates/1
  # DELETE /cms_templates/1.xml
  def destroy
    if params[:source_id]
      # 削除取り消し
      # 公開時削除のためのCmsTemplateを削除します。
      # これは 対象となるCmsTemplateのidが一覧では使い難いため、source_idで制御しています。
      src_template = CmsTemplate.find(params[:source_id])
      # このプロジェクトでのCmsTemplateを検索します。
      cms_template = CmsTemplate.find(:first,
        :conditions => ["cms_project_id = ? and template_code = ? and delete_at_publish = ?", @cms_project.id, src_template.template_code, true])
      cms_template.destroy
      redirect_to :action => "index"
    else
      # プロジェクトで編集対象になっているテンプレートを削除する
      @cms_template = CmsTemplate.find(params[:id], :include => :contents)
      CmsTemplate.transaction do
        cms_pages = CmsPage.find(:all,
          :include => [{:binds => :cms_page}, :titles, :cms_project],
          :conditions => ['cms_binds.cms_template_id = ?', params[:id]])
        cms_pages.each do |cms_page|
          cms_page.titles.each do|title|
            title.destroy
          end
          cms_page.binds.each do|bind|
            bind.items.each do |item|
              item.contents.each do |content|
                content.destroy
              end if item.contents
              item.destroy
            end if bind.items
            bind.destroy
          end
          cms_page.destroy
        end

        @cms_template.contents.each do |content|
          content.destroy
        end
        @cms_template.destroy
      end
      respond_to do |format|
        format.html { redirect_to(cms_templates_url) }
        format.xml  { head :ok }
      end
    end
  end
end
